# Tada AI Python Client

[Tada](https://www.tadatoday.ai/docs/what-we-do) makes doing RAG over documents easy. With a few API calls, you can

1. Perform layout analysis on hundreds of pages of PDF, Word, and other documents
1. Index the content alongside the layout metadata
1. Search and generate markdown for queries
1. Reindex results

## Requirements

Python 3.8+

## Installation & Usage

Install the package directly

```sh
# pip
pip install tada_ai
```

## Getting Started

For complete instructions, please read our [quickstart](https://www.tadatoday.ai/docs/quickstart)

You will need:

1. An account
2. An API Key
3. To install this client

(If you prefer, we have OpenAPI spec available too: https://api.tadatoday.ai/api)
